@@ -189,8 +189,7 @@ def is_user_admin(inp):
     elif isinstance(inp, wsgi.AALAMRequest):
         (_, user_email) = zauth.get_auth_user_id(inp, deny_anon=False)
 
-    return redis_conn.sismember(
-        baseapp_redisify_name("adminusers"), user_email)
+    return user_email in zutils.get_common_rkey('adminusers', 'smembers')
 
 
 class RolesMgmt(wsgi.Middleware):
@@ -211,19 +210,20 @@ class RolesMgmt(wsgi.Middleware):
         url_perms = route.get('permissions', None)
 
         user_perms = []
-        if user_email and not redis_conn.exists(
-                baseapp_redisify_name("permissions-%s" % user_email)):
-            logging.info("Permissions for %s is not cached yet" % user_email)
-            resp = zutils.request_local_server(
-                "POST",
-                "/aalam/base/permissions/cache/%s"
-                % user_email)
-            if resp.status_code not in [200, 404]:
-                logging.error("Unable to cache the user information")
-                raise webob.exc.HTTPInternalServerError()
+        if user_email:
+            rkey = baseapp_redisify_name("permissions-%s" % user_email)
+            user_perms = zutils.get_common_rkey(rkey, 'smembers')
+            if not user_perms:
+                logging.info("Permissions for %s is not cached yet" % user_email)
+                resp = zutils.request_local_server(
+                    "POST",
+                    "/aalam/base/permissions/cache/%s"
+                    % user_email)
+                if resp.status_code not in [200, 404]:
+                    logging.error("Unable to cache the user information")
+                    raise webob.exc.HTTPInternalServerError()
+                user_perms = zutils.get_common_rkey(rkey, 'smembers')
 
-        user_perms = redis_conn.smembers(baseapp_redisify_name(
-            "permissions-%s" % user_email))
         user_perms = [int(x) for x in user_perms]
         if not user_perms and not from_internal:
             # This should be a valid user account but has not permissions
