@@ -98,12 +98,14 @@ def cleanup():
     except Exception:
         pass
     logging.warn("Killing the wsgi server")
-    wsgi_listener.kill()
 
     def terminate_now():
         sys.exit(100)
 
     def terminate_delayed():
+        eventlet.sleep(1)
+        #Not killing from the thread to honour its response
+        wsgi_listener.kill()
         logging.warn("Terminating after a delay of %s seconds"
                      % CLEANUP_WAIT_PERIOD)
         eventlet.sleep(CLEANUP_WAIT_PERIOD)
@@ -114,7 +116,24 @@ def cleanup():
     # Timer(CLEANUP_WAIT_PERIOD, terminate_now, ()).start()
 
 
-class UnixDomainHttpProtocol(eventlet.wsgi.HttpProtocol):
+class UnixDomainHttpProtocol3(eventlet.wsgi.HttpProtocol):
+    def __init__(self, conn_state, server):
+        client_address = conn_state[0]
+        if client_address == '':
+            client_address = ('<local>', 0)
+            conn_state = (client_address, *conn_state[1:])
+        # base class is old-style, no super does not work properly
+        eventlet.wsgi.HttpProtocol.__init__(self, conn_state,
+                                            server)
+    def get_environ(self):
+        env = super(UnixDomainHttpProtocol3, self).get_environ()
+        # without this, any unicode character passed to the url path is
+        # throws an error
+        env['PATH_INFO'] = urllib_parse.unquote(env['RAW_PATH_INFO'], 'iso-8859-1')
+        return env
+
+
+class UnixDomainHttpProtocol2(eventlet.wsgi.HttpProtocol):
     def __init__(self, request, client_address, server):
         if client_address == '':
             client_address = ('<local>', 0)
@@ -122,7 +141,7 @@ class UnixDomainHttpProtocol(eventlet.wsgi.HttpProtocol):
         eventlet.wsgi.HttpProtocol.__init__(self, request, client_address,
                                             server)
     def get_environ(self):
-        env = super(UnixDomainHttpProtocol, self).get_environ()
+        env = super(UnixDomainHttpProtocol2, self).get_environ()
         # without this, any unicode character passed to the url path is
         # throws an error
         env['PATH_INFO'] = urllib_parse.unquote(env['RAW_PATH_INFO'], 'iso-8859-1')
@@ -316,10 +335,11 @@ paste.app_factory = %(factory)s
         from greenlet import GreenletExit
 
         try:
-            eventlet.wsgi.server(sock, app, custom_pool=self._pool,
-                                 protocol=UnixDomainHttpProtocol,
-                                 log_output=False, log=log,
-                                 debug=True)
+            eventlet.wsgi.server(
+                sock, app, custom_pool=self._pool,
+                protocol=UnixDomainHttpProtocol3 if sys.version_info[0] == 3 else UnixDomainHttpProtocol2,
+                log_output=False, log=log,
+                debug=True)
         except GreenletExit:
             pass
 
